summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorThomas Arnhold <thomas@arnhold.org>2014-05-19 11:52:41 +0200
committerThomas Arnhold <thomas@arnhold.org>2014-05-19 20:04:26 +0200
commit9d498d23dc26265af8d858f842c18caefe7584fd (patch)
treeb7f0c5ae9893ad9718c46d09acc47e46d8d32790
parentbbbbbfc18616c81cf39efb122cf83dbf1b0c1006 (diff)
fix-includes.pl: extend this to resource files, too
Change-Id: Icd95ef188aa04ce25a1c251701aa27a5516b5077
-rwxr-xr-xsolenv/bin/fix-includes.pl6
1 files changed, 3 insertions, 3 deletions
diff --git a/solenv/bin/fix-includes.pl b/solenv/bin/fix-includes.pl
index 6460ad28ee2c..2b3553f63b8a 100755
--- a/solenv/bin/fix-includes.pl
+++ b/solenv/bin/fix-includes.pl
@@ -49,7 +49,7 @@ sub check_headers
}
}
# If a local file is defined global, make it local
- elsif($line =~ /#include <((\w*)\.(hxx|h))>/){
+ elsif($line =~ /#include <((\w*)\.(hxx|h|hrc|src))>/){
# check if file exists, then it must be local so replace the <> to ""
if(-e "$dir/$1" ){
print "global header $line\n";
@@ -69,13 +69,13 @@ sub check_headers
close($fh);
}
# routine that checks the headers of every cxx,hxx,c,h file in a directory
sub check_routine
{
my ($dir) = @_;
opendir(my $fh, $dir) or die "Program stopping, could't open directory \n";
while(my $file = readdir($fh)){
- if($file =~ m/\.(cxx|hxx|c|h)$/i ){
+ if($file =~ m/\.(cxx|hxx|c|h|hrc|src)$/i ){
check_headers($dir,"$dir/$file",@subdirs);
}
}
@@ -69,13 +69,13 @@ sub check_headers
close($fh);
}
-# routine that checks the headers of every cxx,hxx,c,h file in a directory
+# routine that checks the headers of every cxx,hxx,c,h,hrc,src file in a directory
sub check_routine
{